@@ -1,4 +1,4 @@
 from rescape_python_helpers.pyramda.function.curry import curry
 
 
-filter = curry(lambda p, xs: [x for x in xs if p(x)])
+filter = r_filter = curry(lambda p, xs: [x for x in xs if p(x)])
